pub async fn plugin_version<R: CommandRunner>(
stripe: &StripeProjects<R>,
) -> Result<String, ProjectsError>Expand description
Probe the installed plugin version via stripe projects --version
(which prints a bare X.Y.Z line).
pub async fn plugin_version<R: CommandRunner>(
stripe: &StripeProjects<R>,
) -> Result<String, ProjectsError>Probe the installed plugin version via stripe projects --version
(which prints a bare X.Y.Z line).